ensure_session_unexpired

Function ensure_session_unexpired 

pub(crate) async fn ensure_session_unexpired(
    session: &Session,
    session_data: TowerSessionData,
) -> Result<AuthedUser, AuthError>
Ensures the session is still valid by checking for expiration, and returns the associated user if the session remains active.