execute_request

Function execute_request 

pub(super) async fn execute_request<S: ResultSender>(
    client: &mut AuthedClient,
    request: SqlRequest,
    sender: &mut S,
) -> Result<(), Error>
Executes an entire SqlRequest.

See the user-facing documentation about the HTTP API for a description of the semantics of this function. Executes a SQL request and sends results to the provided sender.

Made visible to http submodules (like mcp) via pub(in crate::http) to allow reuse of SQL execution logic.