pub(crate) async fn ensure_session_unexpired(
session: &Session,
session_data: TowerSessionData,
) -> Result<AuthedUser, AuthError>Expand description
Ensures the session is still valid by checking for expiration, and returns the associated user if the session remains active.